@@ -358,7 +358,8 @@
       (mell-marker-set 'prime-cand-list-begin (point))
       (prime-disp-cand-list-one)
       )
-     ((or prime-cand-mode); prime-conv-mode)
+     ((or prime-cand-mode
+	  (and prime-conv-mode (eq prime-style-display-candidates 'all)))
       (end-of-line)
       ;; marker $B$H$N7s$M9g$$$G$A$g$C$HD>46E*$G$J$$$3$H$K$J$C$F$$$k(B.
       (insert "\n")
@@ -366,7 +367,7 @@
       ;;
       (prime-disp-cand-list-all)
       )
-     (t
+     (t ;; prime-conv-mode is here.
       (let (col)
 	(goto-char prime-curstr-begin)
 	(setq col (+ (% (current-column) (window-width))
@@ -377,7 +378,9 @@
 	(mell-marker-set 'prime-cand-list-begin (point))
 	;;
 	(insert (make-string col 32)) ; 32 = space
-	(prime-disp-cand-list-one)
+	(if (eq prime-style-display-candidates 'fixed)
+	    (prime-disp-cand-list-fixed)
+	  (prime-disp-cand-list-compact))
 	)))
     ;; marker $B$H$N7s$M9g$$$G$A$g$C$HD>46E*$G$J$$$3$H$K$J$C$F$$$k(B.
     (mell-marker-set 'prime-cand-list-end (point))
@@ -395,7 +398,7 @@
 ;      (setq i (1+ i))
 ;      )))
 
-(defun prime-disp-cand-list-one ()
+(defun prime-disp-cand-list-compact ()
   (let ((i 0)
 	(offset (+ prime-nth-cand (if prime-conv-mode 1 0))))
     (while (and (< i 10) ;(if prime-conv-mode 10 3))
@@ -410,6 +413,42 @@
       )
     ))
 
+(defun prime-disp-insert-highlighted (string)
+  (let (beginning end)
+    (setq beginning (point))
+    (insert string)
+    (setq end (point))
+    (font-lock-prepend-text-property
+     beginning end 'face 'prime-cand-cursor-face)
+;;; $B$3$l$O(B XEmacs only
+;;;	    (font-lock-set-face beginning end 'prime-cand-cursor-face)
+    ))
+
+(defun prime-disp-cand-list-fixed ()
+  (let ((i 0))
+    (while (and (< i (length prime-cands))
+		(< i 10))
+      (cond
+       ((and prime-enum-mode  ;; prime-enum-mode
+	     (or prime-conv-mode (not prime-enum-mode-ignorep))
+	     (< i (length prime-enum-char-list)))
+	(let ((string (concat (char-to-string (nth i prime-enum-char-list))
+			      (prime-nth-candidate i)
+			      " ")))
+	  (if (and prime-conv-mode
+		   (= i prime-nth-cand))
+	      (prime-disp-insert-highlighted string)
+	    (insert string))))
+       (t ;; under the normal mode
+	;; FIXME: Remove this checking routine using prime-conv-mode.
+	;; FIXME: (2005-02-16) <Hiroyuki Komatsu>
+	(if (and prime-conv-mode
+		 (= i prime-nth-cand))
+	    (prime-disp-insert-highlighted
+	     (concat "[" (prime-nth-candidate i) "]"))
+	  (insert "(" (prime-nth-candidate i) ")"))))
+      (setq i (1+ i)))))
+
 
 (defun prime-disp-cand-list-all ()
   (let ((i 0))
@@ -418,15 +457,8 @@
 	      (window-width))
 	   (insert "\n"))
       (if (= i prime-nth-cand)
-	  (let (beginning end)
-	    (setq beginning (point))
-	    (insert "[" (prime-nth-candidate i) "]")
-	    (setq end (point))
-	    (font-lock-prepend-text-property
-	     beginning end 'face 'prime-cand-cursor-face)
-; $B$3$l$O(B XEmacs only
-;	    (font-lock-set-face beginning end 'prime-cand-cursor-face)
-	    )
+	  (prime-disp-insert-highlighted
+	   (concat "[" (prime-nth-candidate i) "]"))
 	(insert "(" (prime-nth-candidate i) ")"))
       (setq i (1+ i))
       )))
